declare module '@doraemon-ui/miniprogram.tools' {
  /**
   * Get rollup config
   *
   * @export
   * @param {RollupConfig} opts 构建配置
   * @returns {{
   *     inputOptions: RollupInputOptions
   *     outputOptions: RollupOutOptions
   *   }}
   */
  export function getRollupConfig (opts: RollupConfig): {
    inputOptions: RollupInputOptions
    outputOptions: RollupOutOptions
  }

  /**
   * Powered by rollup
   *
   * @export
   * @param {{
   *     inputOptions: RollupInputOptions 入口配置
   *     outputOptions: RollupOutOptions 输出配置
   *   }} { inputOptions, outputOptions }
   */
  export function startBuild ({ inputOptions, outputOptions }: {
    inputOptions: RollupInputOptions
    outputOptions: RollupOutOptions
  }): Promise<void>

  /**
   * Execute for gulp4
   *
   * @export
   * @param {({
   *     _: string | string[],
   *     onStartMsg?: string,
   *     onCloseMsg?: string
   *   })} [opts]
   * @returns {(void | Promise<void>)}
   */
  export function execute(opts?: {
    _: string | string[],
    onStartMsg?: string,
    onCloseMsg?: string
  }): void | Promise<void>
}

interface RollupConfig {
  entry?: string
  outputFile?: string
  format?: 'esm'
  copy?: any[] | boolean
  libraryName?: string
  bundleDependencies:? boolean
  internals?: any[]
  namedExports?: { [key: string]: any }
  env?: { [key: string]: any }
}

interface RollupInputOptions {
  input?: string
  external?: any[]
  plugins?: any[]
  inlineDynamicImports?: boolean
}

interface RollupOutOptions {
  file?: string
  format?: 'esm'
  name?: string
  sourcemap?: boolean
  banner?: string
}
